
# Services being monitored
MONITORING_SERVICES = [
    {'name': _('OverCloud Services'),
     'services': [
         {'name': 'compute',
          'display': _('Compute')},
         {'name': 'object',
          'display': _('Object Storage')},
         {'name': 'block',
          'display': _('Block Storage')},
         {'name': 'image',
          'display': _('Image')},
         {'name': 'network',
          'display': _('Network')},
         {'name': 'mysql',
          'display': _('MySQL')},
         {'name': 'rabbitmq',
          'display': _('RabbitMQ')},
         {'name': 'monitoring',
          'display': _('Monitoring')},
     ]},
]
